@@ -4,4 +4,6 @@
 # manually move them to the original one and restart
 # the applications using it.
 
-cp $HOME/.rtcom-eventlogger/el.db $HOME/.rtcom-eventlogger/backup.db
+cd $HOME/.rtcom-eventlogger/
+tar czf backup.tgz el.db plugins attachments
+
