@@ -556,11 +556,25 @@ gint rtcom_el_get_flag_id(
  * @param error A GError** to be set on failure
  * @return TRUE on succes, FALSE in case of failure
  */
-gboolean rtcom_eventlogger_update_remote_contact(RTComEl *el,
+gboolean rtcom_el_update_remote_contact(RTComEl *el,
     const gchar *local_uid, const gchar *remote_uid,
     const gchar *new_abook_uid, const gchar *new_remote_name,
     GError **error);
 
+/* For backwards compatibility */
+#define rtcom_eventlogger_update_remote_contact(a,b,c,d,e,f) \
+	rtcom_el_update_remote_contact(a,b,c,d,e,f)
+
+/**
+ * Removes any association with the specified abook uid.
+ * @param el the #RTComEl object
+ * @param abook_uid the abook ID for the contact
+ * @param error A GError** to be set on failure
+ * @return TRUE on success, FALSE in case of failure
+ */
+gboolean rtcom_el_remove_abook_uid (RTComEl *el,
+    const gchar *abook_uid, GError **error);
+
 /** Fire EventUpdated DBus signal (only to be used from plugins, to signal their state changed).
  * @param el The RTComEl object.
  * @param event_id The id of the event that should be signalled as updated.
